<?php
// Push CSS to the document
//
// The css() method provides a quick and convenient way to attach stylesheets. 
// 
// 1. The name of the stylesheet to be pushed to the document (file extension is optional). 
//    If no name is provided, the name of the component or plugin will be used. For instance, 
//    if called within a view of the component com_tags, the system will look for a stylesheet named tags.css.
// 
// 2. The name of the extension to look for the stylesheet. For components, this will be 
//    the component name (e.g., com_tags). For plugins, this is the name of the plugin folder 
//    and requires the third argument be passed to the method.
//
// Method chaining is also allowed.
// $this->css()  
//      ->css('another');

$this->css();

// Similarly, a js() method is available for pushing javascript assets to the document.
// The arguments accepted are the same as the css() method described above.
//
// $this->js();
?>
<header id="content-header">
	<h2><?php echo JText::_('COM_DRWHO'); ?></h2>
</header>
<section class="main section">
	<?php if ($this->getError()) { ?>
		<p class="error"><?php echo $this->getError(); ?></p>
	<?php } ?>

	<form action="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=save'); ?>" method="post" id="hubForm">
		<div class="explaination">
			<p><?php echo JText::_('COM_DRWHO_HELP'); ?></p>
		</div>
		<fieldset>
			<legend><?php echo JText::_('COM_DRWHO_DETAILS'); ?></legend>

			<label for="field-name">
				<?php echo JText::_('COM_DRWHO_NAME'); ?> <span class="required"><?php echo JText::_('JOPTION_REQUIRED'); ?></span>
				<input type="text" name="entry[name]" id="field-name" size="35" value="<?php echo $this->escape(stripslashes($this->entry->name)); ?>" />
			</label>

			<label for="entrycontent">
				<?php echo JText::_('COM_DRWHO_BIO'); ?> <span class="required"><?php echo JText::_('JOPTION_REQUIRED'); ?></span>
				<textarea name="entry[bio]" cols="35" rows="10" id="entrybio"><?php echo $this->escape(stripslashes($this->entry->bio)); ?></textarea>
			</label>

			<div class="grid">
				<div class="col span-half">
					<label for="field-friend">
						<input type="checkbox" name="entry[friend]" id="field-friend" value="1" <?php if ($this->entry->get('friend', 0)) { echo ' checked="checked"'; } ?> />
						<?php echo JText::_('COM_DRWHO_FRIEND'); ?>
					</label>
				</div>

				<div class="col span-half omega">
					<label for="field-friend">
						<input type="checkbox" name="entry[enemy]" id="field-enemy" value="1" <?php if ($this->entry->get('enemy', 0)) { echo ' checked="checked"'; } ?> />
						<?php echo JText::_('COM_DRWHO_ENEMY'); ?>
					</label>
				</div>
			</div>
		</fieldset>
		<div class="clear"></div>

		<input type="hidden" name="id" value="<?php echo $this->entry->get('created_by'); ?>" />
		<input type="hidden" name="entry[id]" value="<?php echo $this->entry->get('id'); ?>" />
		<input type="hidden" name="option" value="<?php echo $this->option; ?>" />
		<input type="hidden" name="controller" value="<?php echo $this->controller; ?>" />
		<input type="hidden" name="task" value="save" />

		<?php echo JHTML::_('form.token'); ?>

		<p class="submit">
			<input class="btn btn-success" type="submit" value="<?php echo JText::_('COM_DRWHO_SAVE'); ?>" />
		</p>
	</form>
</section>